package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,``@$!````<"4```````!``````````+C#````
M````0P```$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````E`````````"4``````````0`````````!````
M!0```````````````````````````````````,"R````````P+(`````````
M0`````````$````&````X+T```````#@_0```````.#]````````R`0`````
M```0%0````````!``````````@````8```#PO0```````/#]````````\/T`
M```````0`@```````!`"````````"``````````$````!````&`"````````
M8`(```````!@`@```````$0`````````1``````````$`````````%#E=&0$
M````Q*H```````#$J@```````,2J````````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````."]````````X/T```````#@_0``
M`````"`"````````(`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UL
M;V]N9V%R8V@M;'`V-&0N<V\N,0`````$````%`````,```!'3E4`2E>FKM(9
MR`M"&^F=;8*3:R4J\'X$````$`````$```!'3E4```````4````3````````
M``````"I````90````````!`````(````"(``````````````$0`````````
M`````$@`````````0P`````````P````&P```"P`````````*P```$<`````
M```````````````)````````````````````/0```"H```!!`````````$P`
M````````"P```%8```!)`````````````````````````$8`````````````
M`!P`````````%0```"\````,````7P```&0````\````-````#<````6````
M)0```%L```!-``````````````!7```````````````7`````````!D`````
M````70`````````D````60```!T`````````3P`````````Q````````````
M```2`````````",````I````$P````````!4````40``````````````2P``
M`$4````````````````````?````2@````````````````````````!C````
M`````&(```!:``````````T````/``````````````!5```````````````U
M````.````#L`````````````````````````````````````````````````
M`````````````#8`````````&``````````^````+@```%(`````````*```
M``````!0`````````#D````'`````````!H```````````````````!.````
M+0````````!3`````````%P````*```````````````````````````````S
M`````````#\``````````````````````````````!X`````````````````
M````````)P``````````````````````````````````````````````````
M`````````````````````````````````````````````````!``````````
M``````````````````````````!8````````````````````````````````
M````````````````````````````````````(0``````````````%```````
M`````````````````````````````!$`````````````````````````````
M```````````````````````.`````````#H``````````````&``````````
M`````````````````````$(`````````)@``````````````````````````
M````,@```&$```````````````````````````````````!>````````````
M```````````````````(````````````````````````````````````````
M`````````````````"L```!.`````@````<```":A9`!"6`$2`B.%$&*A!#H
M3@``````````````3P``````````````4```````````````40````````!2
M`````````%0``````````````%4```!6`````````%<```!8````60``````
M``!:````6P```````````````````````````````````%P```!=````7@``
M`%\```!@``````````````!B`````````&,``````````````(D'<--K&IY0
MH^#[2>-'Q@%FK\QF0T75[+OCDGRS`8MO;\7?'Q6,)<POQ9NV(?_D#ONA;&##
MY3\LS]Y'+=EQ6!Q_J9R;X:<""D+ZUX=K?YI\,V+;[=1DU'RM2^/`````````
M``````````````````````````````,`#0"@(@``````````````````````
M``,`#@!8;`````````````````````````,`$`"@JP``````````````````
M``````,`%`````$```````````````````````,`%@"@`@$`````````````
M``````````,`%P"P`@$`````````````````6@$``!(`````````````````
M````````!0(``!(`````````````````````````I0```!(`````````````
M````````````PP(``!(`````````````````````````[`$``!(`````````
M````````````````_@(``!$`````````````````````````J`$``!(`````
M````````````````````@P```!$`````````````````````````R@```!(`
M````````````````````````:`$``!(`````````````````````````&`$`
M`!(`````````````````````````-P(``!(`````````````````````````
MSP(``!(`````````````````````````DP(``!(`````````````````````
M````+@$``!(`````````````````````````0`(``!(`````````````````
M`````````0```"``````````````````````````'0(``!(`````````````
M````````````'0```"``````````````````````````:P(``!(`````````
M````````````````DP```!(`````````````````````````#P$``!(`````
M````````````````````FP```!(`````````````````````````#P(``!(`
M````````````````````````=@$``!(`````````````````````````T```
M`!8`````````````````````````XP```!(`````````````````````````
MNP$``!(`````````````````````````N@```!(`````````````````````
M````_@```!(`````````````````````````*`(``!(`````````````````
M````````-P```!(`````````````````````````"@(``!(`````````````
M````````````>0(``!(`````````````````````````9`(``!$`````````
M````````````````'P$``!(`````````````````````````C0(``!(`````
M````````````````````Y0$``!(`````````````````````````PP,``!(`
M````````````````````````/`$``!(`````````````````````````M0(`
M`!(`````````````````````````3`$``!(`````````````````````````
M1@(``!(`````````````````````````D@$``!(`````````````````````
M````4P(``!(`````````````````````````]P$``!(`````````````````
M````````BP```!(`````````````````````````W0(``!(`````````````
M````````````;P$``!(`````````````````````````BP$``!(`````````
M````````````````Z0(``!(`````````````````````````20```"(`````
M````````````````````V0$``!(`````````````````````````P0```!(`
M````````````````````````6````!(`````````````````````````B`(`
M`!(`````````````````````````S`$``!$`````````````````````````
M1`$``!(`````````````````````````7@```!(`````````````````````
M````10(``!(`````````````````````````4P$``!(`````````````````
M````````\P```!(`````````````````````````F0$``!(`````````````
M````````````<````!(`````````````````````````K````!(`````````
M````````````````?0$``!(`````````````````````````30(``!(`````
M````````````````````@`(``!(`````````````````````````@0```!$`
M````````````````````````80$``!(`````````````````````````HP(`
M`!(`````````````````````````1P0``!$`%``X``$```````@`````````
MIP,``!(`#0"@6````````.@"````````400``!(`#0"@3@```````%@#````
M````5`,``!(`#0!`30```````#``````````FP,``!(`#0"`30````````@!
M````````(00``!``%@"H`@$`````````````````#P0``!``%P#P$@$`````
M````````````=P,``!(`#0``4@```````!0!````````S`,``!(`#0!`50``
M`````,0!````````!@0``!(`#0#`5````````'``````````0P,``!(`#0!`
M2@````````0`````````.@0``!(`#0!@2@```````-P"````````*`0``!(`
M#0!@4P```````&`!````````\@,``!(`#0`@20```````"``````````%`0`
M`!(`#0"@6P```````.P+````````^@,``!``%P"H`@$`````````````````
ML0,``!(`#0`@4P```````"@`````````A0,``!(`#0!`20`````````!````
M````YP,``!(`#0`@5P```````'`!````````1````!(`#0"@(@```````-`"
M````````_P,``!(`#0!P)0```````&``````````80,``!(`#0"@9P``````
M`)0$````````V`,``!$`#@!8;`````````0``````````%])5$U?9&5R96=I
M<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%]?
M;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE`&%B;W)T`%]?<F5G:7-T
M97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``
M;W!E;F1I<@!R96%D9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK
M`&-L;W-E9&ER`')M9&ER`%!,7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,
M;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L86=S`')E861L:6YK`&UE
M;6-H<@!097)L7W-V7W-E='!V;@!097)L7W-V7W-E='!V`&UE;6UO=F4`<F5A
M;&QO8P!G971P:60`;65M8W!Y`'-T<F-H<@!S=')T;VL`<W1R8VUP`&%C8V5S
M<P!S=')D=7``7U]S=')N8W!Y7V-H:P!G971U:60`<W1R<W1R`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,
M7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L
M7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`
M<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`97AI=`!L<W1A=#8T`&UK9&ER`%]?
M97)R;F]?;&]C871I;VX`<W1D97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`&QS
M965K-C0`<F5A9`!C;&]S90!097)L7V=V7V9E=&-H<'8`4&5R;%]S=E\R<'9?
M9FQA9W,`4&5R;%]A=E]F971C:`!097)L7V=E=%]S=@!097)L7V%V7W-H:69T
M`%!E<FQ?;6=?<V5T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]?<W1A8VM?8VAK
M7V=U87)D`&QI8G!E<FPN<V\`;&EB8RYS;RXV`&QD+6QI;G5X+6QO;VYG87)C
M:"UL<#8T9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`<VAA
M7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,V`"]U<W(O;&EB
M+W!E<FPU+V-O<F5?<&5R;"]#3U)%``````````````````````(``0`"``$`
M`0`#``$``@`"``(``@`!``$``0`!``(``0`!``$``@`"``(``@`!``(``0`!
M``$``@`!``$``@`"``(``@`!``(``@`"``(``0`"``(``@`"``$``@`!``(`
M`@`!``(``0`"``(``@`!``(``@`"``(``0`!``(``@`"``(``@`"``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`````````0`!`"4#```0````(````+:1E@8```,`7@0````````!``$`&P,`
M`!``````````MI&6!@```@!>!````````.#]`````````P````````#@)@``
M`````.C]`````````P````````"`)@````````@``0```````P````````#@
M;0```````!```0```````P````````!PJ@```````!@``0```````P``````
M``!XJ@```````"```0```````P````````"`J@```````"@``0```````P``
M``````"(J@```````#@``0```````P`````````(<````````$@"`0``````
M`P````````"@9P```````)@"`0```````P`````````X``$``````*`"`0``
M`````P````````"@`@$``````#`"`0```````@````P``````````````#@"
M`0```````@````T``````````````$`"`0```````@````X`````````````
M`%`"`0```````@```!<``````````````%@"`0```````@```!D`````````
M`````&`"`0``````"P```"```````````````&@"`0```````@```"$`````
M`````````'`"`0```````@```"(``````````````'@"`0```````@```"D`
M`````````````(`"`0```````@```#H``````````````(@"`0```````@``
M`#\``````````````)`"`0```````@```$$``````````````%```0``````
M!0````<``````````````%@``0``````!0````@``````````````&```0``
M````!0````D``````````````&@``0``````!0````H``````````````'``
M`0``````!0````L``````````````'@``0``````!0````\`````````````
M`(```0``````!0```!```````````````(@``0``````!0```!$`````````
M`````)```0``````!0```!(``````````````)@``0``````!0```!,`````
M`````````*```0``````!0```!0``````````````*@``0``````!0```!4`
M`````````````+```0``````!0```!8``````````````+@``0``````!0``
M`!@``````````````,```0``````!0```!H``````````````,@``0``````
M!0```!L``````````````-```0``````!0```!P``````````````-@``0``
M````!0```!T``````````````.```0``````!0```!X``````````````.@`
M`0``````!0```!\``````````````/```0``````!0```",`````````````
M`/@``0``````!0```"0````````````````!`0``````!0```"4`````````
M``````@!`0``````!0```"8``````````````!`!`0``````!0```"<`````
M`````````!@!`0``````!0```"@``````````````"`!`0``````!0```"H`
M`````````````"@!`0``````!0```"L``````````````#`!`0``````!0``
M`"P``````````````#@!`0``````!0```"T``````````````$`!`0``````
M!0```"X``````````````$@!`0``````!0```"\``````````````%`!`0``
M````!0```#```````````````%@!`0``````!0```#$``````````````&`!
M`0``````!0```#(``````````````&@!`0``````!0```#,`````````````
M`'`!`0``````!0```#0``````````````'@!`0``````!0```#4`````````
M`````(`!`0``````!0```#8``````````````(@!`0``````!0```#<`````
M`````````)`!`0``````!0```#@``````````````)@!`0``````!0```#D`
M`````````````*`!`0``````!0```#H``````````````*@!`0``````!0``
M`#L``````````````+`!`0``````!0```#P``````````````+@!`0``````
M!0```#T``````````````,`!`0``````!0```#X``````````````,@!`0``
M````!0```$```````````````-`!`0``````!0```$(``````````````-@!
M`0``````!0```$,``````````````.`!`0``````!0```$0`````````````
M`.@!`0``````!0```$4``````````````/`!`0``````!0```$8`````````
M`````/@!`0``````!0```$<````````````````"`0``````!0```$@`````
M``````````@"`0``````!0```$D``````````````!`"`0``````!0```$H`
M`````````````!@"`0``````!0```$P``````````````"`"`0``````!0``
M`$T``````````````,X!`!RMO1$`S\'%**U1_P+,P<4"K05%`(PAP"C@`0!,
MSP$`'.^!Q2CM`0!,``!``\\!`!SO8<4H[0$`3```0`//`0`<[T'%*.T!`$P`
M`$`#SP$`'.\AQ2CM`0!,``!``\\!`!SO`<4H[0$`3```0`//`0`<[^'$*.T!
M`$P``$`#SP$`'._!Q"CM`0!,``!``\\!`!SOH<0H[0$`3```0`//`0`<[X'$
M*.T!`$P``$`#SP$`'.]AQ"CM`0!,``!``\\!`!SO0<0H[0$`3```0`//`0`<
M[R'$*.T!`$P``$`#SP$`'.\!Q"CM`0!,``!``\\!`!SOX<,H[0$`3```0`//
M`0`<[\'#*.T!`$P``$`#SP$`'.^APRCM`0!,``!``\\!`!SO@<,H[0$`3```
M0`//`0`<[V'#*.T!`$P``$`#SP$`'.]!PRCM`0!,``!``\\!`!SO(<,H[0$`
M3```0`//`0`<[P'#*.T!`$P``$`#SP$`'._APBCM`0!,``!``\\!`!SOP<(H
M[0$`3```0`//`0`<[Z'"*.T!`$P``$`#SP$`'.^!PBCM`0!,``!``\\!`!SO
M8<(H[0$`3```0`//`0`<[T'"*.T!`$P``$`#SP$`'.\APBCM`0!,``!``\\!
M`!SO`<(H[0$`3```0`//`0`<[^'!*.T!`$P``$`#SP$`'._!P2CM`0!,``!`
M`\\!`!SOH<$H[0$`3```0`//`0`<[X'!*.T!`$P``$`#SP$`'.]AP2CM`0!,
M``!``\\!`!SO0<$H[0$`3```0`//`0`<[R'!*.T!`$P``$`#SP$`'.\!P2CM
M`0!,``!``\\!`!SOX<`H[0$`3```0`//`0`<[\'`*.T!`$P``$`#SP$`'.^A
MP"CM`0!,``!``\\!`!SO@<`H[0$`3```0`//`0`<[V'`*.T!`$P``$`#SP$`
M'.]!P"CM`0!,``!``\\!`!SO(<`H[0$`3```0`//`0`<[P'`*.T!`$P``$`#
MSP$`'._A_RCM`0!,``!``\\!`!SOP?\H[0$`3```0`//`0`<[Z'_*.T!`$P`
M`$`#SP$`'.^!_RCM`0!,``!``\\!`!SO8?\H[0$`3```0`//`0`<[T'_*.T!
M`$P``$`#SP$`'.\A_RCM`0!,``!``\\!`!SO`?\H[0$`3```0`//`0`<[^'^
M*.T!`$P``$`#SP$`'._!_BCM`0!,``!``\\!`!SOH?XH[0$`3```0`//`0`<
M[X'^*.T!`$P``$`#SP$`'.]A_BCM`0!,``!``\\!`!SO0?XH[0$`3```0`-C
M@/X"86#!*7@@P2EW0,$I>0#!*7K@P"G8`0`:&,/(*`P#`":-`!4`94#`*68@
MP"EE0,`"9B#``F1PP`)LH,`I;7"`*?\__U?&`0`:QN#(*,0!`!J$P,DHQ0`5
M``!$253,`0`:C"'**(P!`"J`X0%`S`$`&HR!R2A7_088``!``XT)##AD'``D
MK`D2*H04@`*$#$$`C`V``ZP)$BG_9_Y7;4#`**SG!AB/`0`FK@$`)F8<`"0,
M$(`"458"&'!6`ACL8H`IY$+`*0P$@`*1(,`ID&#`*8]`P"F.```GAP`5`(;U
M`&3(Y+\"#`B``HC)`60$((`"%!R``A,8@`(2%(`"$1"``A`(@`(,!(`"#B"`
M`@``0`.O.0PX)0Y!`*ZY$`#`@<(J[Q0<.`X.00"N.0PX20Y!`(^!0`#N)!PX
MC@F``LX-00"J.0PX;@Y!`(PA@`+J.!PXJA4,.(4.00`0(H`"ZA0<.*HE##B)
M#$$`,2*``NHD'#BJ.0PXC@U!`%(B@`+J.!PXJA4,..4E@`*E#$$`ZA0<.*4E
M##CO*8`"[PU!`.4\'#AS(H`"E"*``H0@@`((9O]CK;D0`*\!`":.#8`"S@U!
M`(P%@`+O.!PXK2'``H;I_V/&#(`"Y"+`*,P,00`(`!4`Y0$!&.`P'#C_I_I7
MF0`5`("$`$#D(L`H>I#``O^3_%?D1P(810,5```T'%2`>`!`Y"+`*/]+^E?_
M5_M7;:#`*`P#`":LG0!<86#!*'=`P2AX(,$H>N#`*"0#%0!Y`,$H8X#!`B``
M`$S_U_I7E^X&&.0BP"F`<`!`_U?[5\P!`!J,@<DHC0D,.*W]WP*@P0@I_P_^
M4^0BP"C_5_I7F0`5`/]W_U/D@L`H@`P`0``0,%3_@_]310,5`&0\`A@`H!M4
MY(+`*9]L_T,`]"]4_V?_4PP$@`(.((`"__O^4P``0`/_S_Q7!`2``O]'^E>)
M`!4`!```&@R`R@(,```6C`$``X2P$`!E`,`H9B#``@,`@P`'`!4`"``5`&H`
M%0`!```:#(#!`@P``!:,`0`#(;`0`"$``$P!```:#`#'`@P``!:,`0`#(;`0
M`"$``$P``$`#``!``P``0`,``$`#8\#_`G8@P"EV0,`"I-(&&(S2!AB$'0!8
MS`$`&HQ!R2B`$0!`=B#`*&-`P`*``0!,=B#`*&-`P`(@``!,``!``P31!ACE
MT`88I9`1`&/`_P*L#$D`I?Q%`'8@P"FEL!``=D#``J4$20"@'`!`S`$`&HQA
MR2B`$0!`=B#`*&-`P`*``0!,=B#`*&-`P`(@``!,``!``P``0`,``$`#``!`
M`V.`_P)V0,`I=R#`*6%@P"EV@,`"]^`&&.P"`"J`+0!$S`$`&HP!RBB`$0!`
MK-\&&(0!`";_W_I7_RO_5PP$@`+L`@`I``!``V%@P"AV0,`H=R#`*&.`P`(@
M``!,``!``V/`_P)V(,`I=D#``G8@P"AC0,`"_R__4P``0`,``$`#8X#T`G=`
MRREX(,LI>0#+*7K@RBE\H,HI?8#**7Y@RBEA8,LI>\#**7]`RBG&`0`:QL#(
M*(C@P"C,```F\0$`%#$"O`.-.``D;"#**0RA10"'`,$H#H%%`(S%%``(X44`
MC"$5`,AA00`/_@$4A2#!*`@!WP"M,0``SB%!`,Z]%`",(14`K<%,`.B@10",
M.14`K0'?`.Z`10`(Q10`Y^!%``@=%0!M(,`IQV%!`*V@10#G`-\`;$#`*:W%
M%`"L@$4`SB%!`*7@10#.O10`"!T5`*T5%0"%84$`"#D5`(PA00"N`-\`C+T4
M`)Y``"2<2``DK3D5`(Y0`"2M,14`C%@`)-XS``"<,P``SC$``-[#3`"<PTP`
MSL%,`(PQ``#>`]\`G`/?`,X!WP",P4P`C`'?`'Y@P"EH@,`I?*#`*6W`P"EN
MX,`IDH#!*)1`P2B38,$HD*#!*(7`P2AL(,$IC&``)'BB10`+HD4`C#$``(S!
M3`",`=\`;&#!*8QH`"1Y@D4`"H)%`(PQ``",P4P`C`'?`'/B10`8QQ0`$.)%
M`&O%%`!LH,$IC*)%`(>"10",Q10`E.)%`!A/%0!K014`4Z)%`#!C00!7@D4`
MFE$5`!`"WP!,XD4`<L84`#,C00`00Q4`<[X4`!-.%0!S0,$I\V)!`%(R%0#P
M(D$`<P+?`%-.%0`0OA0`<$(5`'"`P2E084$`G7``)%(A00`0`M\`J8!%`%*^
M%`#L8$$`]"!!`'!!%0"GH$4`$$H5`.?$%`"EX$4`,F%!`#$A00!2`M\`O3,`
M`(P!WP#G%!4`E+X4`.=(%0`OOA0`O<-,`$PS%0"]`]\`C%$5`.<\%0!L`,$I
M<,#!*7W@P2EQ0,,"$D"``A,P@0)G`,(IRP,5`)0!%0`^XOTH+.+\*,\!%0`)
M`14`S+,5`(S!%0",K14`C@5!`(Q]10`H`OXHSC$5`"P"_2B%`Q4`/"+^*`RQ
M%0",]14`C*45`(D%00",?44`*3$5`"PB_2BJ`14`+4+^*(RS%0",G14`C)45
M`(5]10",!4$`I3`5`"Q"_2C.`=\`+N+^*:RQ%0",N14`C*D5`)!]10",!4$`
M+F+^*!`R%0`L8OTH*0'?`*4`WP#,L14`C*45`(R]%0"=?44`C`5!`"^"_2B]
M,Q4`+(+^*!`"WP"]`]\`C[T5`.^5%0#OT14`YWU%`.\%00#G/!4`(`+`*BD"
M_RDE(O\I,$+_*3UB_RGG`-\`4AJ``B>"_RDQPL`"4^[^7Y(``":30,`HA6#`
M*'@@P"B4(,`HD8#`*.D$M10I9:8#6FY%`&U`P"A.%D$`;Y85`,YI%0`8IQ``
M&,<0`._1%`#.`=\`[Y45`*VE$`":"D4`SN$0`(QZ00",:14`:F#`*%H*10#.
MO1``KY40`$UZ00"M:14`FP'?`,X!WP",M14`2J40`'_N%0",N10`_\L4`$K-
M$`",[14`>8#`*-@500",J1``_\\5`,IM10`8*Q4`_[\0`/_C$`#_`]\`.:<0
M`#GO$`#X%T$`^V]%`'>@P"C*>4$`S@E%`$HY%0`.;Q4`N@'?`(RY$`"MJ14`
MC`'?`/>F$`"M_10`FVU%`/?J$`#N>T$`K>D5`/\+10":%4$`SGT5`%IO%0"M
MY1``6`'?`*WI$`!*N14`K0'?`)MY00!KP,`H2K$4`(P)10!L,Q4`2N$5`+H5
M00"[;44`V0'?`%?=$`#.L14`2F\5`&NE$`#.M10`]ZH0`/<"WP!KX1``SN45
M`+IY00#*K1``>.#`*.YN10#_%D$`K0E%`$TW%0![`,$H_SL5`)H!WP!*_1``
MC+45`$H!WP",W10`&*<0`.YZ00#W"D4`SET5`(OI%0`8YQ``3!5!`'FG$`!;
M;44`=R#!*#GK$`!KX1``FFT5`+@!WP"MN14`K:D4`&OI$`!K`=\`K>$5`$QY
M00!*"44`C"D5`'L500"JY1``[:80`'=M10#:`=\`>4#!*'M?%0#.L14`SJT4
M`$KM$`!*`=\`U^D5`*WA$`!N>4$`:PE%`,XM%0!;;44`*Z<0`/>V$`!-%4$`
MF`'?`&OI$`",N14`NFT5`(RI%`#WZA``]P+?`(SA%0!->4$`2@E%`*TI%0!Y
M8,$HZFY%`(NM$`#L%D$`>X#!*-H!WP",*14`SK45`,[=%`!KL1``:P'?`,KI
M%0`YIQ``[GI!`/<*10#.714`;*<0`#GC$`![;44`=Q5!`/=N%0!*Y1``N`'?
M`$K=$`"MN14`2@'?`)KI$`!YH,$HK:T4`&QY00!K"44`C"T5`*WA%0!+;44`
M6Q5!`-<!WP![+Q4`K>D0`,ZQ%0#.J10`.:<0`*WM$`"M`=\`>L#!*,O=%0`Y
MXQ``3GE!`$H)10#.*14`:^40`+@500"Y;44`FP'?`!AG%0",N14`2J<0`(RU
M%`!KX1``:P'?`%?=$`",[14`>&U%`*IY00",W1``K0E%`'<500!*-14`]V(5
M`-H!WP",W1``SJD5`)<!WP#.K10`;7E!`&L)10"M+14`_VY%`.L600!OH,<H
M:WT5`'^@R"A9`=\`2K45`/_]%0#PPQ4`;\#'*'_`R"@>^A4`T']%`._]%0#O
MH14`[_45`-X'00!]X,@H$'H5`.A]10!^X,<H[P5!``@]%0!O`,DH?T#(*!`"
MWP#=]Q4`?@#(*`^^%0"]\Q4`_/T5`*^?%0"<^Q4`YWU%`.\%00#G/!4`CP=!
M`)Q_10#O<14`"`'?`.<`WP#O`=\`<*#)*6C`R2EGX,DI;P#**7W@P2A\`,(H
M?B#"*+VG$`#.Z14`G*<0`-ZG$`"[[Q``2MT4`$KE%0":ZQ``W.<0`-GM$``K
MKQ``:P'?`$[I$`#L>D$`>FU%`/<*10!Y%4$`?H#"*(Q=%0`Y:Q4`?4#"*'M@
MPBBX`=\`SN40`*VQ%0#.`=\`K:T4`-FG$`#:;44`O:<0`&IY00"MX14`:PE%
M`'NG$`#)%4$`2BT5`"EI%0"M\1``EP'?`*VE$`",J14`K0'?`,MY00",N10`
MS@E%`+WC$`![WQ``C-T5`'<Y%0"N;44`JQ5!`%@!WP!K.14`C/40`$K=%0!*
MM10`J7E!`(RM$`"M"44`BP'?`"DU%0!\H,(H2N$5`#GC$`!*[1``[:85`'MM
M10!X%4$`SK/=%,Z%K@/Z`M\`K:T4`!AO%0"<NQ``K>D5`!@#WP"<ZQ``NN40
M`$WA$`"J`=\`;'E!`&L)10",+14`76U%`$L500`[`=\`=\#"*'D`PR@IL14`
M:W45`"FU%0!K`=\`37E!`$H)10!:KQ``K2D5`"D!WP"8`=\`J@'?`/>Z$``I
M\1``.;L0`%P#WP",M14`G6]%`/?N$`",Z14`>^#"*#FK$`"*%T$`:R##*(P!
MWP!*=14`FGM!`/>R$`!*`=\`C`M%`"FI$`!:,Q4`>[L0`#P!WP!,`]\`>^,0
M`&NY$`!X0,,HK>D5`&NQ$`"MI14`C'M!`(D+10",)14`K0'?`!B[$`![MQ``
MC0'?`(D700`8MQ``C6]%`"TU%0"M`=\`][80`.D"WP!:LQ4`/&U%`%K?%0`W
M%4$`]W(5`"UY00#W`M\`*0E%`*TE%0![WQ``:F##*'P#WP",M14`G6]%`(SM
M%0";%T$`MP'?`&F`PRA*N1``6@/?`(P!WP![=Q4`.>L0`$K=$`!KL1``EWM!
M`(P+10![`]\`.>\0`/<R%0`]`]\`*;D0`.P"WP!ZH,,HK=T5`#RQ$`"MY14`
MJ0M%`*Q[00",)14`K0'?`%J[$``8MQ``C0'?`*D700!:MQ``K6]%`"TU%0"M
M`=\`:[40`&D!WP#WLA4`.6U%`/>N%0`K%4$`>\##*&ME%0`M>4$`:P'?`"D)
M10`8KQ``K245`!T#WP"I`=\`>[L0`(RU%0#W`M\`C.$5`'NG$`"K%T$`J6]%
M`$K=$`",`=\`=^##*&LE%0"X>T$`B;,0`&L!WP"L"T4`&#,5`$RM$`"<`=\`
M"P/?`'D`Q"CWNA``K>$5`/>N$`"ML14`BPM%`(Q[00",+14`K0'?`#F[$`!:
MMQ``C0'?`(L700`YMQ``C6]%`&TU%0"M`=\`+;40`*D!WP`\;44`*Q5!`!BS
M%0!K<14`&+<5`&L!WP`M>4$`*0E%`*TE%0!:KQ``70/?`(RU%0!J(,0HC.D5
M`+P700"Z;T4`:4#$*!@#WP",`=\`G&L5`'OC$`#WLA``N'M!`*P+10"<`]\`
M&#,5`*L!WP!L\Q``2KD0`)P!WP`IN1``2JT0`*WA%0!K8,0H&@/?`#KI$`"M
ML14`B0M%`(Q[00",)14`K0'?`&NY$``YMQ``C0'?`&NU$`");T4`C1=!`*TE
M%0"M`=\`][80`.D"WP`8LQ4`/&U%`!C?%0`W%4$`>X#$*/=R%0`M>4$`]P+?
M`"D)10`YWQ``K245`#P#WP"I`=\`>[L0`(RU%0`8`]\`C.45`'NG$`"9%T$`
MB6]%`$KA$`",`=\`>*#$*#DG%0"=>T$`2;,0`#D#WP","T4`O3,5`$SE$`"*
M`=\`N0/?`!B[$`"M]14`7!5!`!CG$`"ML14`60E%`$QY00!*;44`BBL5`$H!
MWP`IJ1``*@'?`(QE%0!>;44`7!5!`+VS%0"<>Q4`K0'?`&VU$`"]IQ4`G`/?
M`$EY00!*"44`*2D5`*WQ$`"J`=\`BP'?`(RE%0",M14`7!5!`%YM10"]`]\`
MC`'?`)Q[%0!WP,0H>_<0`$UY00`8LQ``2@E%`(P#WP"M*14`>[,0`'K@Q"AY
M`,4H:@/?`#T!WP`IM14`7&U%`/>Z$``I[14`6Q5!`/>N$`"L`=\`>W,5`&L@
MQ2A:NQ``.;L0`"D!WP!N-QX5.;,0`/RF$`!,>4$`:0/?`$H)10#.<;,##@``
M%HPI%0`8IQ``"@/?`&NY$`"ML14`FP'?`'OM$`"MX14`2Q5!`%AM10!W0,4H
M:V$5`$EY00!K`=\`2@E%`"DI%0"<KQ``BP/?`/BZ$``J`=\`6O<0`!BK$`!W
M;44`:A5!`*T!WP!-MQ``C*45`$I=%0!Z>4$`MZD0`(SQ%0!K"44`]P+?`$TO
M%0",`=\`*S45`/IN10!\8,4H++,0`.H600"Y`=\`:]T4`$II%0`IY10`:245
M`(RI$`#K>D$`]PI%`&M=%0"*`=\`G+L0`'?E%`"<YQ``6FU%`%D500`Y:Q4`
M*>T0`*TM%0"MJ10`*>40`"D!WP"M714`3'E!`$H)10",*14`?8#%**KA$``X
M;44`+15!`'<Q%0"M814`F@'?`/>F%``X>4$`2K40`"D)10`8)Q4`2@'?`*F[
M$`![`=\`:^D4`"WM$`!YH,4H6VU%`.LN%0",814`5Q5!`/=N%0!K\1``C*D4
M`!SK%`!KW1``C'$5`#N[$`!)>4$`C+40`$H)10!M`=\`*2D5`'OK$`"\;44`
MNA5!`#D!WP`*)Q4`6G,5``OG%`!*M10`C.D0`(P!WP!*+14`JWE!`*T)10!K
M-14`G&U%`'?`Q2B:%4$`6G,5`$KM$``I+14`>^#%*&WE%``IL10`2ND0`$H!
MWP`8`]\`][H0`"DU%0"->4$`C`E%`*TQ%0#WXA``;+L0`%QM10!;%4$`>W,5
M`"G=$`!X-14`MP'?`"GM$``I`=\`>@'?`!BK%`!KW10`>P#&*(SE$``];44`
M&"\5`%EY00`\%4$`2@E%`#DK%0"<=Q4`&+,0`*UE%0`8\Q``&`/?`#W?%`!J
MNQ``:R#&*"QY00"MI10`*0E%`(PE%0!:Z1``"6]%`*UU%0`*%T$`2B45`*WI
M$`![N1``*3,5`(L!WP"MJ1``J@'?`#RO%`!Z0,8H*>$4`'O?$``I<14`%WM!
M`%QM10`8"T4`315!`/=B%0"M<14`*>T0`"FU$``Y`]\`C%T5`%J[$`#XKA0`
M6N<0`(RI%``Y`=\`*6]%`'M@QBB,814`37E!`#@700!*"44`K2D5`!@G%0",
MZ1``J@'?`.DV%0",X1``C`'?`/BJ%`![NQ``*>44`'NO$`"<%4$`G6U%`"L+
M10!Z@,8H*6$5`#A[00`8+Q4`*>T0`(MW%0`IK1``K6$5`#D!WP`;JQ0`6KL0
M`*VQ%`#W`M\`5]\0`&N@QB@Z%T$`G'E!`*UM%0")"44`.V]%`(PG%0"MW1``
M26\5`)<!WP"MI1``"3,5`+L!WP`<WQ0`:[D0`"GE%`!MJ1``>L#&*"EQ%0!J
M%T$`?&]%`"M[00`Y"T4`:V45`$IQ%0`IM1``*:D0`(PM%0!JX,8H3;L0`'S=
M%``Z`=\`C.T4`!@#WP"XX1``66]%`$D700!M>T$`C'$5`'L+10"M;14`*645
M`$JY$`",X1``6]T0`(RE$`"W`=\`:345`)@!WP`IZ10`;-T4`'D`QR@<;T4`
M2GM!`"DQ%0!:"T4`#!=!`$II%0",<14`*>T0`"FQ$`"M*14`6]T4`"R[$`!K
M`=\`.0'?`*WA%`")K1``>B#'*"L700"M;14`#'M!`#MO10`8"T4`C&$5`*VE
M$`!I;14`K:40`(L!WP!),14`K0'?`%NM%`!:NQ``*>44`%K?$`"\;44`>$#'
M*"EM%0`W>T$`NQ5!`#D+10#W9A4`*>D0`'IS%0`IZ1``C%T5`"D!WP#\KA0`
M>V#'*$H!WP`8NQ``C+44`!BK$``Z;44`.15!`(QQ%0"J>4$`.6L5`(SA$`"M
M"44`3345`'N[$`",Y1``C`'?`'NO$`#J-A4`JP'?`/VN%`"<;44`>(#'*#EY
M00!*I10`FA5!`"D)10`Y)Q4`6G,5`$IU%0#I`M\`2NT0`%<#WP"M914`.J\4
M`$K=$`"ML10`&+L0`*UI%0`8IQ``6@'?`*[A$`!IH,<H6&]%`)=Y00!<%T$`
MC`E%`(W%E!7W,A4`G&,5`*U9AP,-```6+-\5`)P#WP#<\1``*;40`(JI%0!.
M"T4`C`/?`"FM$`!;>T$`2@'?`$NE$`![.Q4`>,#'*(YM10"*%4$`2CD5`.GN
M%0!*`=\`.0/?`!BW$``I\14`?*D0`(H#WP`8YQ``*0'?`)EY00`IX1``C`E%
M`%AM10!+%4$`.3,5`&[@QRAL`,@H:V$5`&L!WP`IK1``6'E!`$H)10`8*Q4`
M*P'?`/H"WP#.M1``=^<5`(RU$`![`]\`]_(5`,[I$`!\;44`.N,5`(SM$``[
M`]\`>15!`/<"WP`Y<Q4`SMT0`%JG%0`Y`]\`:7E!`&L)10`I+14`SN40`,L!
MWP`9IQ4`=R#(*%H#WP#JMQ``&`/?`'QM10",Z1``2N$0`'I@R"AX%4$`&',5
M`/>V$``YNQ4`&`/?`&YY00!K"44`SBT5`(SA$`#W[A``6K<0`#L!WP!:[Q``
M*;D5`)L!WP!];T4`*;$5`'P700"<=Q4`.0/?`"D!WP#WYA``2J40`&Q[00!I
M"T4`FP/?`(PE%0#I[A``/`'?`-@!WP!K@,@HSK$5`)UO10!YH,@HSJ45`)L7
M00!WP,@HS@'?`'MW%0!:NQ``:[40`(X+10")>T$`>P/?`"DY%0!KX1``3NT0
M`)@!WP`YMQ``VP'?`#P!WP`YXQ``][80`'C@R"B,I14`[[40`/?R$`",N14`
M?`M%`._)$`!R>T$`4G(5`(P!WP!NL1``&+<0`$P"WP`8LQ``;!=!`'MO10",
M;14`C`'?`$RS$`":`=\`6Q=!`%UO10`\R14`:@#)*'MW%0"<LQ4`>P/?`$Q[
M00!:"T4`C&D5`,[M$`#;`=\`F@'?`$JU$`"<`]\`4K(5`#GS$`!2NA4`?&]%
M`$KI$`!Z%T$`:R#)*%("WP!:<Q4`]\H0`&Y[00!R"T4`6@/?`,Y)%0`RZQ``
M6P+?`-H!WP!KM1``:^D0`'QO10!Z%T$`C+D5`%IS%0",R14`6@/?`/SJ$`!I
M0,DH>6#)*'>`R2B,`=\`<GM!``RS$`!X"T4`4F(5`)@#WP`0MA``"+40`.>T
M$``IM1``.;<0`/>V$``;%T$`#6]%`'LW%0![`]\`#7M!`!@+10"M814`C.T0
M`)L!WP#.R14`6@+?`+@!WP!2MA4`4K(5`#CC$`!L;T4`SO$5`'D700`Y,Q4`
MS@'?`%("WP!*N1``.ND0`&P+10!IR1``;GM!`#(#WP#.,14`2LD0`%D!WP"M
MN14`+&]%`*VI%0`J%T$`2C$5`*T!WP`R>T$`3+<0`#D+10!-`=\`+;40`%)F
M%0"J`=\`RP'?`$D"WP#KKA``":80`%=M10!0%4$`SLD5`!!>%0#.M14`$`+?
M`$UY00!*"44`K2D5`(S!$`"0`=\`4K85`*H!WP!2LA4`"JD0``P600`(;D4`
MS@'?`(PA%0`7NQ``C`'?``YZ00`0"D4`SD$5`.RR$`"0`=\`R`'?`%("WP!R
MR1``Z*`0``MN10`'%D$`K;D5`.<L%0"ML14`YP#?``QZ00`0"D4`C$$5`%*>
M$`!0`M\`SK$5``=N10"M`=\`SLD5`!(600`IM1``4AX5`(T!WP#OM1``4@+?
M``UZ00`0"D4`K4$5`##)$``2`M\`1Q9!`$EN10",M14`S@'?`.<D%0",P14`
MYP#?`%!Z00!.N1``4@I%`,Z=$``02A4`$I80`+'%$`"MP14`T`'?``4600`'
M;D4`C`'?``RQ$`"E'!4`K;D5`(R5$``.>D$`C`'?`*T!WP`0"D4`[[40`,U!
M%0".%4$`D&U%`,Y!%0",T1``C`'?`*W-$`#NN1``K0'?`(P@P"G,`=\`C```
M)XU`P"EM(,HHS```)C$"WP!2`M\`DF#`*9&`P"FL-0!<86#+*'=`RRAX(,LH
M>0#+*'K@RBA[P,HH?*#**'V`RBA^8,HH?T#**&.`RP(@``!,_U_A5P``0`,`
M`$`#8P#_`F'@P"EWP,`I@.P`0'T``">,`0`:C`')*)T!`":@XP!`>F#`*7M`
MP"EY@,`IC```*)H`%0"[`!4`@`T`0(P-_P*`?0!$&0`5````0`.W`P`FX+X`
M0'B@P"E\(,`IN`,5`!ST@`(F`Q4`10,5`.0"%0#_[]]7@`P`1.QF(#B<80!8
M%R/`*!@CP`+_WO]'>*#`*'F`P"AZ8,`H>T#`*'P@P"A]```F8>#`*.0"%0!W
MP,`H8P#!`B```$P``$`#F0`5`"P'`"@Y!\`"C0W_`H`)`$"_\?]'.6L1`/]W
M_U,8]Q$`.0?``A@/20#WYA``>`,`)?^?_U,7`!4`_Z__4WT``"87`!4`_Z/_
M4P``0`-Y@,`H>F#`*'M`P"A]```F_XO_4P``0`,``$`#``!``P``0`,``$`#
M``!``P``0`-C`/\">T#`*6'@P"E]```GFP$`&GL#R2A]`P`FH)L`0'F`P"EZ
M8,`I=\#`*7B@P"E\(,`IF0`5`"P#`"@:](`"@-$`0(P-_P*`R0!`/`,5`(P'
M`"B<!\`"C0W_`H`)`$"_\?]'G&<1`+@#`"8`-P!`MP,5`(8#%0`E`Q4`!`,5
M`/^CWE>`#`!$#',@.)H]`%CX(L`H]R+``A_?_T<``$`#=\#`*'B@P"AY@,`H
M>F#`*'P@P"AAX,`H>T#`*'T``"9C`,$"(```3.SV$0!O`P`FC`U)`(R!0`",
M#4$`[;$0`*XAP"CN,1PXP!D`0```0`.L0<`HK2'``JP!`">?]?]'?0,`)K^?
M_T,L`P`HGSG_1QP`%0#_5_]3``!``P``0`-C`/T">8#"*6'@PBF9`0`:.</(
M*"P#`"9L(,(I@!@`0'?`PBF,```JEP`5`(`E`$1WP,(H;2#"*"P#`":L,0%<
M8>#"*'F`PBAC`,,"(```3'B@PBEZ8,(I_TO<5Y@`%0"`V`!`!`,5`/];W%>`
MO`!`C$P`*II,P`*,2;\"@!$`1$P'`"J?X?]#``!``XQ,`"J,2;\"@+4`0```
M0`/D`A4`>T#"*?\OVU>;`!4`1`,5`/\CVU=D$Q``A`B``O^WW%=)`Q4`Z`(5
M`,="`1@&_+\"!02``IH`%0#_*]Y792#``D0#%0#_W]Q7#/R_`HP<`%AL&``D
M[@$`%(T``!2,N10`C(%``(U=`%A$`Q4`_^?;5T0#%0#_']Q7!`,5`'M`PBC_
MH]M7GTS_1P0#%0#_1]U7Y`(5`/_/VE=WP,(H>*#"*'I@PBC_\_Y33`<`*HQ)
MOP*?3?]'3`L`*I\-_T/_0_]31`,5`/^?_E?_J_]3=\#"*7B@PBEZ8,(I>T#"
M*?]WW5=CP/\"=P``)Y<!`!KW@LDH82#`*><M`QCD"@PXA@$`&L:@R2@E/`$8
M_RO=5^0*##AA(,`H=P``)DA8`1@)`!4`!A4!&`<!%0`%/`$88T#``O\SVU,`
M`$`#``!``P``0`-C`/\"[?__%7?`P"EXH,`I>8#`*7I@P"EAX,`IF`$`&AC#
MR"ACM!``S___%2T``!0,`P`F[^&_`ZU!@`.MO1``F@`5`+D`%0`&_+\#I8T0
M`(0Y`1AL"!`G_WO:5Y>`0``7=`!D[?Z_`FQ`P`*,M1``C.$_*H!9`$![$!`G
MV___%2P``!1[X[\#C$&``XSM$`";C1``Y@(5``6\@`)D`Q4`_Z/95X!X`$",
M`0`:C(')*&8#%0#G`A4`A`D,.$4#%0#_L]I7>Q`0)@`D`%"@60!$``!``XP!
M`!J,@<DH)@,5`$4#%0"$"0PX_YO95VT($"8,`P`FK$$`7"T``!1CM!``8>#`
M*'?`P"AXH,`H>8#`*'I@P"AC`,$"(```3'L0$";_M_]3>Q`0)[<!%0#_4_]3
M``!``WL0$"?_V]M7``!``V.`_@)X`,$I>L#`*6%@P2EW(,$I>>#`*7N@P"E\
M@,`I?6#`*7Y`P"E_(,`IK0``*@ST@`*Z`!4`F``5`*P)`%RZ!,`"1`,5`/]K
MV%<;`P`HG@$`&MX#R2C=`P`F;`__`@RP$@`;[!(`>[,4`+<#`":<`!4`8.<!
M1!\`%0#@)@)`=D#!*;D#%0`6](`"Y@,5``4#%0#D`A4`_TO:5X`0`$3L?B`X
MEF4!6```0`,W(\`H.2/``O_:_T>L`Q4`&0`5`(TAP"@N`Q4`C"'``CD'@`*_
M\?]'=D#!*,X-@`+$#4$`#-P%&(T!`"2@D0%$#02``HT!`"7_7]E7FP`5`(#<
M`$`W#T$`I0,5`.8"%0#_9]E7VP,`)P``0`,Y!X`".0]!`&!G'#@;`P`HW0,`
M)FP/_P(,L!(`&^P2`'NS%`!@7P%`!`,5````0`.,!``HA`3``HT-_P*`"0!`
MO_'_1X1@$0"<"\`"A),0`/_KV%>D7QPX@&@`0,T#`"8,`P`H&`?``JU=##B.
M#?\"K`$`*<`M`$"`#0!$`"0`4,`A`$`,`P`HK07``A@'P`*L`0`IC@W_`I_I
M_T<``$`##_2``JX%P`(,`!4`KP$`*4TS`#C-,1`XC`7``K_U_T=A8,$H=R#!
M*'@`P2AYX,`H>L#`*'N@P"A\@,`H?6#`*'Y`P"A_(,`H8X#!`B```$S_!\`"
M]_X0`.0"%0#_G]97G"``;#?W$0#W#DD`]X)``'9`P2CW#D$`_P__4P``0`,,
M`!4`33,`..TR$#B,!<`"O_7_1W9`P2C_B_]3``!``Q\#%0#L!P`H_P?``HT-
M_P*`"0!`O_'_1_]C$0#_"_Y3A0`5`*0#%0#_`]E7Q`,`)YL`%0"?3/]#-P]!
M`/^'_E,$`!4`_\?^4P1`@`(9`!4`_SO^4P``0`,``$`#``!``P``0`,``$`#
MC`$`&HR!R2A'"P,8A@$`&L:@R2B$"0PXA1D!&/_7V%-CP/X"82#!*7<`P2EX
MX,`I>J#`*7G`P"F:`0`:6L/(*$P#`";-__\58[00`&P8("?_@]=7U___%4P`
M`!3WPK\#C(&``XS=$`"7C1``)@``%(@`%0#I&`$8!QD!&,8$@`,%!(`"Y`(5
M`/^;V%>X__\53```%!BCOP.,@8`#C.$0`)B-$`#D`A4`)@``%`4#%0#_(]97
MEX!``.!>`&#D!H`"_]/65YD`%0"`%`!`Y@(5``4#%0#_#]A7(%\0.&T8("9,
M`P`FK#D`7$T``!1CM!``82#!*"0#%0!W`,$H>.#`*'G`P"AZH,`H8T#!`B``
M`$P``$`#&0`5`/_'_U/_]]=7_P/_4P``0`,``$`#``!``P``0`,``$`#``!`
M`P``0`-C0/P">$##*7S`PBEAH,,I=V##*7D@PREZ`,,I>^#"*7V@PBGM__\5
MC`$`&HS!R"ACM!``C`$`)HT!`!JM`<DHN0$`)FR($">8`!4`O``5`"!K`D"L
M$`$8F@$5`$T'`"A:!\`"H!$`0*T-_P*_\?]'``!``S<#`"9:,Q$`X#8`0%L/
M`1@=](`"1@,5`&4#%0#D`A4`_T_65X`,`$3L:B`XG0T"6#<CP"@Y(\`"_][_
M1P6\@`($`Q4`_]O35X!8`$`$#@$8!0,5`/\[^U<$`Q4`C`$`&HS!R"AMB!`F
MC`$`)JSM`5PM```48[00`&&@PRAW8,,H>$##*'D@PRAZ`,,H>^#"*'S`PBA]
MH,(H8\##`B```$P$`Q4`?J`0)_^7TU>;`!4`90L!&(0#%0#_]]97>X-``)X`
M%0"`C`%`V?__%2P``!0YX[\#C$&"`XSE$`#0__\5F8T0`"P``!00XKT#C$&"
M`XS!$`!VX!`G?Y@0)WL'@`(<_+\#EHT0`+H(`1C_`0`4';R``LP#`"J`Q0!`
MX!8`0,4#%0#D`A4`_U?35X",`$#$`Q4`_PO35XS\OP+.,R`XA(!``,VS$`#=
M(0!<``!``Z`!`"F$`14`C/V_`LXS(#C-LQ``W>W_6V03$`"$8P!@!02``@H#
M%0!I!0$8R`,5`&<%`1@F```4)`,5`/_CU5?%`A4`)`,5`/^7U%>`'`!$;!@`
M)`T!`!2,_10`C(%``(U5`%@``$`#10,5``0`%0#_[]57G@`5`)],_T=VX!`F
M?J`0)G^8$";_=_Y3X!(`0.P"`"J,2;\"@!$`0-X``1@$!(`"_W?_4^P&`"J?
MO?]#_^__4P4$@`(D`Q4`_X/45Y^H_T<E`Q4`I/\`&/]S^5<D`Q4`_RO35W;@
M$"9^H!`F?Y@0)O\K_E-:!\`"]^H0`/___5,7`!4`__?]4P``0`-^H!`F__O]
M4W;@$"=^H!`G?Y@0)__[U%<``$`#C@``*(T`%0#`)0!`K07``LR]P`.N`0`H
MA#`3`*RQ$P"$,!4`W^G_1R```$P@``!,``!``P``0`,``$`#``!``X```4!C
MP/\"=P``)V$@P"F,```JEP`5`("]`$#_=]%7AOS_`N::$``-O(`"YA8`:``X
M`%#&_/\"YHH`6```0`/,```JC?'_6PV\@`+F%@!H`!@`4,;\_P+F:@!8``!`
M`\P``"J-\?]?#;R``N86`%P`4`!0S```*HT1`%P``$`#QOS_`N;R_VO&W!$`
M+```%,T(P`*-50!HY0(5`"<``!3&!,`"9*8%&/\KU%=A(,`H=P``)N2E!1AC
M0,`"(```3.T"`"H,O(`"A/4`&*P-`%P``$`#)/0`&&$@P"AW```F8T#``O^_
MT5-A(,`H=P``)@0`%0!C0,`"(```3```0`/$\@`8_Y_14P``0`,``$`#``!`
M`P``0`,``$`#``!``V,`_@)AX,$I3-\"&'I@P2E[0,$I?"#!*9H!`!I:P\@H
MD$'`*(]AP"B.@<`HC:'`*%$#`":,P4`J1/0`&'&@P"EP```G;R#`*6Y`P"EM
M8,`I;(!`*?\O\U?$\P`8_R?S5\3S`!C_'_-7!/0`&/\7\U<$]``8_P_S5T3T
M`!C_!_-71.T`&/__\E=$]``8__?R5X3T`!C_[_)7Q/0`&/_G\E<$[0`8G`$`
M&IP#R2C_U_)7FP,`)F"[`4",[0`8>8#!*7?`P2EXH,$I?0#!*7[@P"F9`14`
M+0<`*#D'P`*@#0!`K0W_`K_Q_T=W`P`F.3,1`.!"`$!X`Q4`G>L`&![T@`(F
M`Q4`I0,5`.0"%0#_E]%7@!``1.QF(#B>X0%8``!``Q<CP"@8(\`"_]K_1P``
M0`.,Z@`8F0$5````0`,M!P`H.0?``J`-`$"M#?\"O_'_1W<#`"8Y,Q$`X$(`
M0'@#%0`=Z0`8'O2``B8#%0"E`Q4`Y`(5`/\OT5>`$`!$[&8@.)Z5`5@``$`#
M%R/`*!@CP`+_VO]'``!``PSH`!B9`14```!``RT'`"@Y!\`"H`T`0*T-_P*_
M\?]'?`,`)CDS$0"`0P!`>`,5`)<#%0!]Y@`8'O2``B8#%0"E`Q4`Y`(5`/_#
MT%>`#`!$[&8@.)ZY`%@7(\`H&"/``O_>_T<``$`#3.4`&)<!%0```$`#[08`
M*/<&P`*@#0!`K0W_`K_Q_T?W,A$`@#<`0!CD`!@9](`"Y@(5``4#%0"$`Q4`
M_V?05X`,`$2,7R`XF>D`6'PCP"A[(\`"G]__1W?`P2AXH,$H>8#!*'T`P2A^
MX,`HC*2^%(Q!A0-M1,`H;(BI%HQ1$`.L20!<;61`*FP``!2,.;4#K#D`7&5L
MP`+$XP`8_R?U5P`H`%`E!\`"!-P`&.66$`#_$_57=\#!*'B@P2AY@,$H?0#!
M*'[@P"A%Y``8).$`&/_S]%=MH,`H3`,`)JQE`%QAX,$H>F#!*'M`P2A\(,$H
M8P#"`B```$PE!\`").$`&.66$`#_O_17FP,`)G\G_D?_2_]3)0?``D3A`!CE
MEA``_Z/T5YL#`"9_<_Y'_R__4^4&P`+DW@`8A9<0`/]W_U-WP,$I>*#!*7F`
MP2E]`,$I?N#`*?\_T%<``$`#``!``V,`_P)Z8,`I8>#`*;IO!1A$`P`D#/R_
M`HP4`%AAX,`H>F#`*&,`P0(@``!,>*#`*6P!`!J,`<DHF`$`)@#3`$",VP`8
M>8#`*7?`P"E[0,`I?"#`*9D!%0`M!P`H.0?``JX-_P*@#0!`W_'_1P``0`,7
M`P`F.3,1`.`V`$"[V0`8'/2``B8#%0!E`Q4`Y`(5`/^SSE<8(\`"@`P`1.QF
M(#B</0!8%P,`)O_>_T=WP,`H>8#`*'M`P"A\(,`H!``5`$0#`"5AX,`H>*#`
M*'I@P"AC`,$"(```3```0`/WYA``Y`8`*'F`P"AWP,`HC$#_`@RP$@`$D!(`
M>T#`*'P@P"B$L!0`_[__4P``0`,$`!4`_[/_4P``0`,``$`#``!``V/`_P)A
M(,`I_TO.5X2`0`#_D\U7@`@`0(0``"9A(,`H8T#``B```$P``$`#``!``P``
M0`,``$`#``!``P``0`-C`/\">T#`*6'@P"EXH,`I;`$`&HP!R2B8`0`FFP`5
M``"#`$`LU``8>8#`*7?`P"EZ8,`I?"#`*9D!%0`M!P`H.0?``JX-_P*@#0!`
MW_'_1P``0`,7`P`F.3,1`.`V`$!:T@`8'/2``B8#%0!%`Q4`Y`(5`/]OS5<8
M(\`"@`P`1.QF(#B</0!8%P,`)O_>_T=WP,`H>8#`*'I@P"A\(,`H90,5`"30
M`!@``$`#8>#`*'B@P"A[0,`H8P#!`O]'\E,Y!\`"[&8@./?F$`"?Q?]#90,5
M`.0"%0#_V\Q7@"@`0&'@P"AWP,`H>8#`*'I@P"A\(,`H>*#`*'M`P"AC`,$"
M(```3&0#%0#_J\I7F``5`.0"%0#_G\I7!),0`(0(P`+_,\Q7Z@(5``4$@`(I
MPP`8:`,5`&?#`!@&_+\"EP`5`/^CS5?E`A4`>8#`*'?`P"AZ8,`H?"#`*(3*
M`!C_4_]38\#_`@0`@@)A(,`I_^?+5U";WQ6O=3$5S:6'%5&*SA00)JX#[_FS
M`ZYD(!2MP8<#,0:,`Q```!8/```6SMF1`PT``!:1```GD"#`*8]`P"F.8,`I
MC8#`*8"@P"F`P,`I@."!*6$@P"AC0,`"(```3```0`,``$`#``!``P``0`-C
M@/X"=R#!*7G@P"EA8,$I>Z#`*7U@P"E^0,`IF0`5`/\C^%>-```HEP`5`*`A
M`$"$!,`"K+W``XT``"CW,A,`C+`3`/<R%0"_Z?]'OE,%&,P#`"0-_+\"'>02
M`(UU`%@,L!(`N[,4`&`G`$1A8,$H=R#!*'G@P"A[H,`H?6#`*'Y`P"AC@,$"
M(```3"P#`"J?W?]#!A"``@7"`!CD`A4`_V/+5Y_(_T=A8,$H=R#!*'N@P"A]
M8,`H?D#`*"0#%0!YX,`H8X#!`O\[[5,``$`#>L#`*6P!`!J,`<DHF@$`)D"_
M`$!LO``8?(#`*79`P2EX`,$I?R#`*9P!%0"-!P`HG`?``JX-_P(.N!(`#;02
M`+NY%`!_Z_]'6`,`)IPS$0``BP!`?[H`&!;T@`*&`Q4`Y0,5``0#%0#_R\I7
M6B/``H`,`$0,<R`XEC$`6%@#`"8?W_]'#``5`,P#`"5V0,$H>`#!*'K`P"A\
M@,`H?R#`*/_[_E,``$`#&/,0``T'`"BL0?\"#+`2``VT$@";M10`;`,5`'OW
M%`#_P_]3P`,`)7K`P"C_R_Y3P`,`)79`P2AX`,$H>L#`*'R`P"A_(,`H_Z_^
M4P``0`,``$`#``!``P``0`,``$`#``!``P``0`-C`/\"=\#`*7B@P"EY@,`I
M?"#`*6'@P"E[0,`IC*#`*(_`P"C.=$4`S3`M`*T!WP"LL1(`[[$0`)!X`"3,
MO1``C:#`*8S`P"F9`!4`W``5`+<`%0"8X,`"`,(`1`S\@`*<"0%DG`._`GI@
MP"F:FT0`6P>``GL#WP![&T$`^^X0`/,"`";R(L`H\4+`*/!BP"CO@L`H[J+`
M*.W"P"CLXL`H)`,5`/<"P0(3`P`G$B/`*1%#P"D08\`I#X/`*0ZCP"D-P\`I
M#./`*?\;SU?[MO]?#`"_`EHS'`!<<Q``>F#`*(8#%0!E`Q4`!`,5`/_WR5<\
MXX$I``!``V'@P"AWP,`H>*#`*'F`P"A[0,`H?"#`*&,`P0(@``!,&P"!`GM#
M$0#,;!(`>[,3`,PP$P![,Q4`!,,0`&8#%0#_J\E7+'L`)`T`@0*.;1``+N.!
M*<VM_U\D`Q4`G&\1`/?N$`#_A\Y7___^4P``0`/[`A4`_W?_4P``0`,``$`#
M``!``P``0`-C0/\">B#`*;J@P"AW@,`I>&#`*4P/10"._4`#>4#`*7L``"</
M`+X"8:#`*;G@P`*,_4`#S@6``KO`P"@-X(`"+S,0.,^!0`"W`!4`F``5`*^5
M`60,`($"$!"``HPY$0`MOQ``D&T";`X(@`*.40)L@$4"1.0"%0#_Z\U7X.+`
M*2`CP"D@0\`I(&/`*2"#P"D@H\`I(,/`*0``0`-M8T4`#``5`'%#10"L`8<`
M<"-%`"PBCP`,0I<`3V-%`&QCGP!.0T4`[(&G`$TC10#,H:\`K,&W`$SCOP#D
M`A4`[,+!*?^#S5?L`@`FY`(5`(QA10`,`P`I[`(`)HQ!10`,!P`I[`(`)HPA
M10`,"P`I[`(`)@P/`"GL(L`HC&%%``P3`"GL(L`HC$%%``P7`"GL(L`HC"%%
M``P;`"GL(L`H#!\`*>Q"P"B,844`#",`*>Q"P"B,044`#"<`*>Q"P"B,(44`
M#"L`*>Q"P"@,+P`I[&+`*(QA10`,,P`I[&+`*(Q!10`,-P`I[&+`*(PA10`,
M.P`I[&+`*`P_`"GL@L`HC&%%``Q#`"GL@L`HC$%%``Q'`"GL@L`HC"%%``Q+
M`"GL@L`H#$\`*6&@P"AW@,`H>&#`*'E`P"AZ(,`H>P``)F/`P`+_\\53#."`
M`A"`@`*,.1$`+;\0`)"=`&P.0(`"CGD`;`X@@`*.60!L``!``PX0@`*.,0!L
M#@B``HX5`&R?@?Y#H`$`*?][_E,``$`#H`%`*8SY_P*M"<`"GV7^0__G_U.@
M`0`EC/'_`@X(@`*M$<`"CLW_:__;_U,``$`#H`$`)XSA_P(.$(`"K2'``HZI
M_VO_T_]3H`$`)Z`AP"F,P?\"#B"``JU!P`*.A?]K_]/_4R`_'#B,@?\"#D"`
M`J`AP"F@0<`IH&'`*:V!P`*.5?]K_\?_4Z`!`"G_O_U3H`%`*8SY_P*M"<`"
MGZW]0__K_U,@/Q@XC/'_`@X(@`*M$<`"CI']:__;_U,``$`#``!``P``0`,`
M`$`#``!``P``0`-C`/H"#?__%7L@Q2E\`,4I8>#%*7;`Q2EWH,4I>(#%*7E@
MQ2EZ0,4I?>#$*7[`Q"E_H,0I8[00`&T!`!JMP<@H'"$%&*8!`"8-`0`4#/__
M%9,CP"B20\`HD6/`*)"#P"B/H\`HCL/`*'L!`!I[`\DHK4&$`P<!`!2ML1``
MYR"$`VQ`P`)H0,`"?@,`)JRQ$`#%D``8-(4`&,V0`!CGH!``Y@``)X5A_"F4
M@?PI@*'\*9/!_"F2X?PID0']*9`A_2F/0?TICF']*8TA_"F`0?PI9$#`*<!O
M`$"-@@`8K`$5````0`..!0`HC`7``L`-`$#.#?\"W_'_1]<#`":8-1$`X$(`
M0#F!`!@:](`"``!``P8#%0`E`Q4`Y`(5`/^'Q%>`$`!$[&(@.)KI`U@``$`#
MUR/`*-XCP`+_VO]'``!``_^3Q%>$@$``_]O#5X!,!$"7```FX$8$0.0"%0#_
M%\)7A`1!`(0$P`+_J\-7Z`(`*&1@P"F8`!4``#4`0```0`,9B@`8"(%G``0#
M%0`G`Q4`!OR_`@4$@`+_"\57Z`8`*!@+P`+W!L`"']W_1_K^_Q4,`0`46L.\
M`XQ!A`-M0,`"C.D0`._^_Q6:M1``#`$`%.^!O0.,080#C+T0`)VU$`!V`P`F
M#`$`%![__Q6,080#C/D0`'B"`!@9](`"GK40`,!^`$```$`##`,`*(X-_P+`
MT0)`@,T"0!<#%0#L!@`H]P;``H`-`$",#?\"G_'_1_=B$0```$`#WP(`)N`O
M`$#F`A4`!0,5`.0#%0#_5\-7@`P`1.Y?(#C9)0)8WR+`*-8BP`+_W_]'6"/`
M*``3`$!V`P`F6B/``M^2_T?V_O\5#`$`%-9BO`.,080#;D#``HS9$`#M_O\5
MEKD0``P!`!2M@;T#C$&$`XRU$`"=N1``#`$`%!C__Q6,080#C.$0`/H!`!28
MN1``F0``%%X!`!37`@`FX$8`0.P"`"J`L0)`I0,5`.0"%0#_:\-7@!P`1`QS
M_R2,Z10`C(%``)GM`5B>Z0%8``!``]<BP"C6(L`"_\K_1P``0`/D`A4`_U?`
M5WE@P"B8`!4`)`,5`/]'P%<8$Q``&!.0`@0#%0#_U\%7*P,5`*IY`!B)<``8
MZ`(5`,=[`!@&_+\"!02``IH`%0#_0\-7!0"'`D0#%0#_5\-7#/R_`HP8`%S_
M"\)7B0``)`Q$@`(LP01<``!``^7^_Q4,`0`4I8"]`XQ!A`.,E1``;4#``D0#
M%0"%M1``_Z?"5Y<`%0"`.`!$#`$`%!G__Q6,080#C.40`&]`P`*9O1``+'/_
M).X!`!2-```4C+D4`(R!0`"-I0)8``!``VU`P"AL`0`:C.')*(0!`":G`0`F
M2`,5`*9X`!@%!(`"_R?`5Q@`%0```$`##`$`%&U`P`*,(80#C+40`(T!`"9L
M`0`:C,'(*(P!`":LL0=<#0$`%&.T$`!AX,4H!`,5`';`Q2AWH,4H>(#%*'E@
MQ2AZ0,4H>R#%*'P`Q2A]X,0H?L#$*'^@Q"AC`,8"(```3/<&P`+M7R`X]]\0
M`+_A_4.E`Q4`Y`(5`/^_P5>?T/U'S'/_).T!`!2,M10`C(%``(T``!2-#0!8
M30$`%(VQ_5\%"(`"Y`(5`/__P%>?H/U'Y`(5`/^SOU>7`!4`GT#^1_^C_5,7
M`!4`_U?]4P4(@`+D`A4`_]/`5Y\4_D?D`A4`_X>_5Y<`%0#6(L`"G\C]0_\/
M_E,,!\`"[3(@./>R$`"_)?Q#Y`(5`/^?\E<,`0`4;4#``HPAA`.,M1``C0$`
M)DP!`!J,P<@HC`$`)JRA!EP-`0`48[00`&'@Q2AVP,4H>(#%*'E@Q2AZ0,4H
M>R#%*'P`Q2A]X,0H?L#$*'^@Q"CD`A4`=Z#%*&,`Q@+_^[Y3%P`5`/^+_5,`
M`$`#_O[_%0P!`!3>`[P#C$&$`XSY$`!M0,`"%F<`&!KT@`*>M1``>`,`)@!G
M`$#,`@`H@+D`0(P-_P*`L0!`V0(5`"P'`"@Y!\`"@`T`0(P-_P*?\?]'.5L1
M````0`,7`P`FX"X`0"8#%0#%`A4`Y`(5`/^;OU>`#`!$[&8@.)H]`%@7(\`H
M&"/``O_>_T?>(\`"U@,`)M^2_T<$-(`"_]^^5Y@`%0#W8@`8"$R!`F1@P"G_
M._M3``!``SD'P`+L9B`XY.80`)_)_T/_([Y7EP`5`-XCP`*?O/]#_P.]5X0$
M00"$!,`"_^_Z4QD`%0#_<_]3/GO_)/]'OU>,@$``S%O]7RQS_R0-`(<"C/U'
M`XU)_5\$`Q4`_V>^5W\#`"9N7P`8F``5`-D!%0#@6P!`+`<`*#D'P`*`$0!`
MC`W_`I_Q_T<``$`#_0,`)CD[$0"@-P!`WET`&!;T@`(F`Q4`Q0,5`*0#%0#_
MI[Y7@`P`1*YG(#C6U0%8_2/`*/\CP`*_W_]';$#`*)X!`";$`Q4`_T^\5YF`
M0``,#(`"F34`9"3S_P+%80`8Q),0`/]SO%>`(`!$#!"``BS'`U@Y[[\"S6<@
M.`R\@`*LM0-8``!``XP#`"0-_+\"C0$!6```0`.`&0!$!0`5`,0#%0#_8[U7
MF0`5`("``40E5@`8!%0`&/\OXU?_N[U7B@`5``MF`!BI30`82`,5`"=?`!@&
M_+\"!02``@0#%0#_Y[Y7&?R_`AM$@`+>9``8?4P`&)Q>`!@`0`!0_ZN]5XP`
M`"2;10!<_V^]5_<&@`**`!4`?@``)ZD#%0#K`A4`2`,5`(<#%0`&_+\"!02`
M`@0#%0#_D[Y7!0"'`@0#%0#_I[Y7F;C_6T0#%0#_J[Q7!0,5`,1'`!C_C^)7
M!`,5`/^'[U?_V_M3;4#`*$P!`!J,X<DHA`$`)J<!`"9(`Q4`YE,`&`4$@`+_
MS[M7_ZO[4W8#`";`<@-`[DP`&-L!%0!M!P`H>P?``J`-`$"M#?\"O_'_1]D"
M`"9[.Q$`($L#0+U+`!@?](`"9@,5`*4#%0`D`Q4`__.\5X`0`$0M;R`XOY$"
M6```0`/9(L`HUB+``C_;_T<,`!4`C`,`)?^?_E-L0,`H)`?``J23$`"9`0`F
M_Y>[5X4`%0`D`Q4`_\OE5YX`%0"?(/Y'_Q?^4P8(@`(%N+\"_\.]5_?^_Q4,
M`0`4]^*_`XQ!A`.,W1``;4#``I>U$``&&(`")`,5`.4"%0#_][Q7#0$`%`S_
M_Q6M080#K;$0`&Q`P`*LL1``C>$_*J`1`$2-Y3\J#@R!`JX%`E@&`!4`!0`5
M`"0#%0#_6[U7!`""`O^3NU?,I8<5C,&'`PP``!9/F]\5KG4Q%:UD(!3[_O\5
MC(#`*0P!`!2MV9$#>^._`U"*SA3O):X#SOFS`XQ!A`,0!HP##P``%@X``!:-
M8,`IC.T0`&U`P`*7`!4`D```)X\@P"F.0,`I@*#`*8#`P"F`X($IF[40```0
M`%!E`Q4`Y`(5`/]_\5<&`0`490,5`"0#%0#_'[Q7AH!```;@_V,D`Q4`_]^Z
M5_G^_Q4,`0`4.8._`XQ!A`.,Y1``;4#``IFU$`#E`A4`)`,5`/^W\E?W_O\5
M#`$`%/>"O0.,080#C-T0`&U`P`*7M1``O$(`&/NBP`(H`P`JY`(5`(<#%0`&
M_+\"!02``O<*P`+_%[Q7.0?``G?C_U\-`0`4#/__%:U!A`.ML1``;$#``JRQ
M$`#J_O\5#0$`%$J!O0.M080#K:D0`&Y`P`++3``8:30`&*JY$`!(`Q4`1T4`
M&`;\OP*`(3XI!02``@0#%0#_M[M71`,5`/_?N5<%`Q4`9#$`&/_#WU<$`Q4`
M_[OL5_\/^5-L0,`HF2'`*#]/_$,D`Q4`_U.X5PT,@`*D/?QOC/#_`B2S$``E
M0@`8_WNX5]X3$P`LDQ,`WC,5`/\?_%,Y[Q``+`<`*(U!_P(-M!(`#+`2`(RU
M%`",`P`E_P_\4X_I/RH.!($"[OG]7X[M/RK-\?U?CO$_*@T@@0+-Y?U?C?4_
M*@P4@0*LV?U?!@B``@48OP(D`Q4`_R^[5^4"%0`&I(`")`,5`/]_NE=+10`8
MZ@(5`,DL`!A(`Q4`QST`&`;\OP(%!(`"!`,5`/_+NE?_2_Q3@`,`)?^7^U/_
MJ[I7``!``P``0`,``$`#``!``P``0`-C0/X">@#!*5H!`!I:@\DH8:#!*7=@
MP2EX0,$I>2#!*7O@P"E\P,`I?:#`*7Z`P"E;"PPX3`$`&HP!R2B8`0`F;,,"
M*FS'`BD`:P!`+"T`&)D!%0`M!P`H.0?``J`-`$"M#?\"O_'_1Q<#`"8Y,Q$`
MX$(`0/PK`!@=](`"``!``R8#%0"%`Q4`Y`(5`/\7N5>`$`!$[&8@.)TA`U@`
M`$`#%R/`*!@CP`+_VO]'``!``_]3YE=;"PPX!RR``@8$@`+%-P`89`,5`/\K
MMU>XT@08@``!0(Y`P"@-&P`D#`2``MRAP"B-[0!D=H#!*7]@P"F60``4'T``
M%!D@@`(7`!4`&P2``O\#D`,>`)`"U@*$`P!<`%```$`#C-D4`(T``!2,@4``
MK0&$`XV!`%A$"PPX!PB``@8`%0!N(,`I_[>Y5VX@P"B%`!4`Q`$5`/]GME<-
M&P`D@&@`1&P'@`+W!L`".2/``HWA`F2;`14`1`L,.`<`%0#F`A4`A0,5`/V"
M0`#_P[=7@+`"0(4``"8-0\`HK`P`)*YE##B-_10`K8%``+YY_U\``$`#I4#`
M*,0!%0#_`[97#1L`))^@_T.L_;\"G1D"6```0`-V@,$H?V#`*$0+##@'#(`"
M!@2``B4O`!C_$[97EP`5`(`L`$",0,`H1`L,.*8N`!B%`0`F_P>V5^Q"P"B%
M`0`FK`P`)(Q9U@"`10)$1`L,.`<,@`(&!(`"A2T`&/_/M5>=`!4`@(P`0$P!
M`!J,`<DHF0$`)B!K`$`,&``8FP$5`&T'`"A[!\`"H`T`0*T-_P*_\?]'-P,`
M)GLS$0#@0@!`W!8`&![T@`(``$`#9@,5`(4#%0#D`A4`_R.W5X`0`$3L;B`X
MGGT!6```0`,W(\`H.2/``O_:_T<``$`##4/`**Q#P"BE`0`FA`$`)O_/VE=7
M"PPX!@2``L4H`!CD`A4`_[NT5X4`%0`&*0`8Y`(5`/\KM5=-"PPX3`$`&HP!
MR2B9`0`FH,4"*<P1`!B:`14`(%\`0$T'`"A:!\`"H`T`0*T-_P*_\?]'-P,`
M)EHS$0#@/@!`>Q``&!ST@`)&`Q4`90,5`.0"%0#_<[97@!``1.QJ(#B<Z0!8
M``!``S<CP"@Y(\`"_]K_1P``0`,$0\`H`(/`*?^G\%<$@\`IEP`5`(#\`$`%
M`(<"Y`(5`/]/MU<,!(`"C02``HT-`&R,O/\"@.T`1&&@P2AW8,$H>$#!*'D@
MP2AZ`,$H>^#`*'S`P"A]H,`H?H#`*&/`P0(@``!,.0?``NUF(#@,Q(`"]^80
M`*SI_%_L!@`JG^G\0__?_%,,!(`"C>W]9Q<$@`)$"PPXA0,5`/<&@`+_\[-7
M#!L`).SN_V-V@,$H?V#`*/_/_5.L0\`H1`L,.&8'P`*%`0`FYIH0`/_GLU?_
MF_Y36@?``O?J$``7@\`I_S__4PT;`"2L_;\"G8W]7_^;_U-]`Q4`K/V_`IU]
M_5__B_]31`L,./];M5?_N_U3``!``Z0<`!AV@,$I?V#`*?]SM5=V@,$I?V#`
M*0Q#P"B'`!4`Y@(5`(4!`":D'``8_U.U5P``0`,``$`#``!``PVS!!BG`0`F
M3`$`&HQ!RBB``0!,``````$``@``````)7,O)7,```!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P
M<F]C+W-E;&8O97AE``!E>&4``````"]P<F]C+R5I+R5S``````!005)?5$5-
M4```````````+@````````!005)?4%)/1TY!344`````.@`````````O````
M`````"5S)7,E<P``4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!
M3%]435!$25(`````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X``````````%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4````
M``````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````
M4$%27T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````
M````4$%27U1-4$1)4@```````#$`````````4$%27T-,14%./0```````$Q$
M7TQ)0E)!4EE?4$%42`!P87(M`````"UE````````+2T```````!54T52````
M`%-94U1%30``4$%42``````O=&UP`````%5315).04U%```````````E,#)X
M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````'!A<FP`````
M+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T
M96UP+25U+25U)7,``````````$%21U8`````&`````````!P97)L`````#``
M````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3````!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B([
M"F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF
M:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS
M>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N
M<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H
M*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O
M<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@
M)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA
M9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P
M;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE
M*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M
M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G
M:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L(#`I.PIR96%D
M*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RDI
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*
M)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN
M9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP
M9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M
M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN
M(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O+3Y[
M8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D
M:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@
M("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I
M9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%2
M1U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%
M3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D[
M"F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<
M-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D
M871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E
M9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E
M=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA
M;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\[
M"FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM
M(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@
M(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN
M+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,
M12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA
M;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H
M5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP
M<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D[
M"GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D
M8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2![
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@
M(CPB+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D
M:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@
M,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L
M("1P<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````5$U01$E2``!414U01$E2`%1%
M35``````5$U0``````!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("```````1L#.]@````:````W'?__U@&``"L>O__
M\````#Q\__\$`0``');__TP!``!<E___N`$``'R8__\(`@``_)G__V`"``!<
MFO__A`(``)R;___<`@``7)[__T@#``!\GO__7`,``'R?__^4`P``G)___Z@#
M``!\HO__%`0``+RB__\H!```W*/__V`$```\I___X`0``%RH__\\!0``G*C_
M_U@%``#\J?__O`4``'RJ___<!0``7*S__XP&``#<K?__R`8``-RP__\`!P``
MW+S__W0'``!\P?__Y`<``!```````````7I2``%\`0$;#0,`$````!@```"T
M>?__8``````'`0!$````+````#![___8&0```$0.X`5HEP28!ID(F@J<#IT0
MGA*!`IL,GQ0#?!D*P4371-A$V43:1-M$W$3=1-Y$WT0.`$0+``!H````=```
M`,B4__\D`0```$0.0$B!`I<$4)T06)H*FPR9"&R8!IP.=-A$V43:1-M$W$3=
M1,%(UT0.`$@.0($"EP29")H*FPR=$&"8!IP.6-C9VMO<W4B=$$3=3)D(F@J;
M#)T01-E$VD3;1-U,````X````)R5__\8`0```$0.0$R;#($"G1!DF0B:"I<$
MF`:<#@)PUT381-E$VD3<1,%$VT3=1`X`1`Y`@0*7!)@&F0B:"IL,G`Z=$```
M`%0````P`0``;);__X`!````1`[``4B9"($"7)<$3-=0P4391`X`1`[``8$"
MEP29"$B8!IH*`DR;#`)\VUP*UT381-I$"UB;#$S7V-K;4)<$F`::"IL,```@
M````B`$``)27__]4`````$0.$$27!$R!`F#!1-=8#@````!4````K`$``-"7
M__\\`0```$0.0%B7!)@&F0B:"H$"3`[`(`)4FPP"3-MX#D!$P4371-A$V43:
M1`X`1`[`(($"EP28!ID(F@J;#$3;3`J;#$@+1)L,````:`````0"``"XF/__
MK`(```!$#F!PF`B:#($"EP:9"IL.G!"=$IX4GQ8"4)8$`E36`P0!P4371-A$
MV43:1-M$W$3=1-Y$WT0.`$0.8($"E@27!I@(F0J:#)L.G!"=$IX4GQ9D"M9,
M"UC6````$````'`"```,F___(``````````T````A`(``!B;__\``0```$0.
M4%2!`I<$F`::"ID(5`[00`*D"@Y01,%(UT381-E$VD0.`$@+`!````"\`@``
MX)O__P0`````````:````-`"``#LF___W`(```!$#O`!<`[P(9@(G!"!`I<&
MF0J:#)L.G1("N`H.\`%$P4371-A$V43:1-M$W$3=1`X`1`M(GA0"7)8$GQ8"
MS`K61-Y$WT0+`E#61-Y$WUR>%$3>4)8$GA2?%@``$````#P#``!@GO__,```
M```````T````4`,``(R>__\(`0```$@.$$B7!($"`J`*P4372`X`1`M<"L%$
MUT0.`$0+1,%$UT@.`````'P```"(`P``=)___U@#````1`Z``52!`IH*FPR<
M#@*XF0B7!)@&G1">$@.,`==$V$391-U$WGB7!)@&F0B=$)X25-=$V$391-U$
MWES!1-I$VT3<1`X`1`Z``8$"EP28!ID(F@J;#)P.G1">$@)(U]C9W=Y4EP28
M!ID(G1">$@``6`````@$``!4HO__%`$```!$#D!(F@J!`E0*P43:1`X`1`M,
MF`9<F0B7!)L,G`X"7-=$V43;1-Q,P4381-I$#@!(#D"!`I<$F`:9")H*FPR<
M#DS91-=0VT3<```8````9`0``!BC__\H`````$0.$$2!`EC!1`X`8````(`$
M```\H___8`$```!$#D!4FPR!`I@&8)D(EP2:"IP.`ES71-E$VD3<4,%$V$3;
M1`X`1`Y`@0*7!)@&F0B:"IL,G`YD"L%$UT391-I$W$381-M$#@!$"P)(V437
M1-I$W!P```#D!```.*3__W``````1`X02($"`ES!1`X`````>`````0%``"8
MI/__Q`$```!$#F!8EP:9"H$"FPZ=$IX4`E0*P4371-E$VT3=1-Y$#@!$"V`*
MP4371-M$W43>2-E$#@!("TR:#%R<$)8$F`B?%@)H"M9$V$3:1-Q$WT@+9-;8
MW-](VD26!)@(F@R<$)\62-9$V$3:1-Q$WS````"`!0``?''__]`"````1`Y@
M5($"F`:7!)D(F@H#&`(*P4371-A$VDC91`X`1`L````X````M`4``,BE__]P
M`0```$0.0`)$EP28!ID(G`Z!`IL,9)H*`G3:7`K!1-=$V$391-M$W$0.`$0+
M```T````\`4```RG___H`@```$0.,$2:"F27!)@&F0B;#($"`YP!"L%$UT38
M1-E$VD3;1`X`1`L``'`````H!@``U*G__^P+````1`Z``W0.@(,"FPZ<$($"
ME@27!I@(F0J:#)T2GA2?%@,,!`H.@`-$P4C61-=$V$391-I$VT3<1-U$WD3?
M1`X`1`L"V`H.@`-$P4361-A$V43:1-M$W$3=1-Y$WTC71`X`1`L`;````)P&
M``!@M?__E`0```!$#G!$F@QH@0*7!I@(F0J;#IP0G1*>%`+`E@2?%@+<UD3?
M`\`!"L%$UT381-E$VD3;1-Q$W43>1`X`1`M@E@2?%FC61-]PE@2?%F#6WUP*
ME@2?%D0+2)8$GQ8``````!`````,!P``D+G__Q0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#@)@```````(`F`````````0`````````0`P````````$`````
M````&P,````````!`````````"4#````````#P````````!I!````````!D`
M````````X/T````````;``````````@`````````&@````````#H_0``````
M`!P`````````"``````````$`````````*@"````````]?[_;P````#H!@``
M``````4`````````B!$````````&`````````!`(````````"@````````"'
M!`````````L`````````&``````````5`````````````````````P``````
M``!```$```````(`````````B`4````````4``````````<`````````%P``
M``````!(&0````````<`````````(!<````````(`````````+`'````````
M"0`````````8`````````!X`````````&`````````#[__]O``````$```@`
M````_O__;P````#@%@```````/___V\``````@````````#P__]O`````!`6
M````````^?__;P`````+````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_____P````#@;0```````'"J````````>*H```````"`
MJ@```````(BJ```````````````````(<````````/__________````````
M``#0'@```````-`>````````T!X```````#0'@```````-`>````````T!X`
M``````#0'@```````-`>````````T!X```````#0'@```````-`>````````
MT!X```````#0'@```````-`>````````T!X```````#0'@```````-`>````
M````T!X```````#0'@```````-`>````````T!X```````#0'@```````-`>
M````````T!X```````#0'@```````-`>````````T!X```````#0'@``````
M`-`>````````T!X```````#0'@```````-`>````````T!X```````#0'@``
M`````-`>````````T!X```````#0'@```````-`>````````T!X```````#0
M'@```````-`>````````T!X```````#0'@```````-`>````````T!X`````
M``#0'@```````-`>````````T!X```````#0'@```````-`>````````T!X`
M``````#0'@```````-`>````````T!X```````#0'@```````-`>````````
MT!X```````#0'@```````-`>````````\/T`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````H`(!``````!'0T,Z("A'3E4I(#$S+C(N,"`R,#(S,#<R-R`H
M04]30R!/4RP@0V]R92D``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB
M=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N9V]T`"YS
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````"4````````````````````!````
M````````````````$P````<````"`````````&`"````````8`(````````D
M````````````````````!````````````````````"8````'`````@``````
M``"$`@```````(0"````````(`````````````````````0`````````````
M```````X````!0````(`````````J`(```````"H`@```````$`$````````
M!@`````````(``````````0`````````-````/;__V\"`````````.@&````
M````Z`8````````H`0````````8`````````"````````````````````#X`
M```+`````@`````````0"````````!`(````````>`D````````'````!P``
M``@`````````&`````````!&`````P````(`````````B!$```````"($0``
M`````(<$```````````````````!````````````````````3@```/___V\"
M`````````!`6````````$!8```````#*``````````8``````````@``````
M```"`````````%L```#^__]O`@````````#@%@```````.`6````````0```
M```````'`````@````@```````````````````!J````!`````(`````````
M(!<````````@%P```````"@"````````!@`````````(`````````!@`````
M````=`````0```!"`````````$@9````````2!D```````"(!0````````8`
M```5````"``````````8`````````'D````!````!@````````#0'@``````
M`-`>````````T`,``````````````````!``````````$`````````!^````
M`0````8`````````H"(```````"@(@```````+1)```````````````````@
M````````````````````A`````$````"`````````%AL````````6&P`````
M``!J/@``````````````````"````````````````````(P````!`````@``
M``````#$J@```````,2J````````W`````````````````````0`````````
M``````````":`````0````(`````````H*L```````"@JP```````"`'````
M```````````````(````````````````````I`````X````#`````````.#]
M````````X+T````````(````````````````````"``````````(````````
M`+`````/`````P````````#H_0```````.B]````````"```````````````
M``````@`````````"`````````"\````!@````,`````````\/T```````#P
MO0```````!`"````````!P`````````(`````````!``````````Q0````$`
M```#`````````````0```````,````````!`````````````````````"```
M`````````````````,L````!`````P````````!```$``````$#`````````
M8`(```````````````````@`````````"`````````#0`````0````,`````
M````H`(!``````"@P@````````@````````````````````(````````````
M````````UP````@````#`````````+`"`0``````J,(```````!`$```````
M````````````$````````````````````-P````!````,```````````````
M`````*C"````````*P````````````````````$``````````0`````````!
M`````P````````````````````````#3P@```````.4`````````````````
2```!````````````````````
